@@ -10,7 +10,7 @@
 
 #include "globals.h"
 
-#define VERSION "asp2php 0.75.22 - August 21, 2001\n" \
+#define VERSION "asp2php 0.75.25 - November 23, 2001\n" \
     "Copyright 2001 By Michael Kohn (naken@naken.cc)\n"
 #include "functions.h"
 
@@ -57,8 +57,9 @@ Object Types:
  1: ADODB.Connection
  2: ADODB.RecordSet
  3: ADODB.Command
- 5: File
+ 5: FileSystem Object
  6: JMail
+ 7: CDONTS.NewMail
 
 */
 
