@@ -170,7 +170,11 @@ int t,ch;
       else
     if (t==3) { parse_command_set(newtoken,temptoken); }
       else
+    if (t==5) { parse_filesystem(newtoken,temptoken); }
+      else
     if (t==6) { parse_mail(newtoken,temptoken); }
+      else
+    if (t==7) { parse_new_mail(newtoken,temptoken); }
 
     autoindent();
     fprintf(out,"%s",newtoken);
