@@ -36,9 +36,11 @@ int t,l;
   if (tokentype==2 && strcasecmp(token,"server")==0)
   { parse_server(newtoken); }
     else
+/*
   if (tokentype==2 && strcasecmp(token,"session")==0)
-  { parse_session_properties(newtoken); }
+  { printf("hellllo!\n"); parse_session_properties(newtoken); }
     else
+*/
   if (strcasecmp(token,"instrrev")==0 || strcasecmp(token,"instrrevb")==0)
   {
     tokentype=gettoken(token);
@@ -170,6 +172,12 @@ int t,l;
   {
     tokentype=gettoken(token);
 
+    if (strcmp(token,".")==0)
+    {
+      push(token,tokentype);
+      parse_session_properties(newtoken);
+    }
+      else
     if (strcmp(token,"(")==0)
     {
       push(token,tokentype);
@@ -518,7 +526,11 @@ int t,l;
       else
     if (t==3) { parse_command(newtoken,temptoken); }
       else
+    if (t==5) { parse_filesystem(newtoken,temptoken); }
+      else
     if (t==6) { parse_mail(newtoken,temptoken); }
+      else
+    if (t==7) { parse_new_mail(newtoken,temptoken); }
   }
     else
   if (isfunction(token)==1)
